Author: Lea Wiemann
Date: 2017-06-10

# Docutils Mailing Lists

Author: | Lea Wiemann
Contact: | docutils-develop@lists.sourceforge.net
Revision: | 8111
Date: | 2017-06-10
Copyright: | This document has been placed in the public domain.

All discussion about Docutils takes place on mailing lists.

There are four different lists with traffic related to Docutils. For an oversight, see https://sourceforge.net/p/docutils/mailman/. If unsure, use the Docutils-users mailing list:

# Docutils-users

The Docutils-users mailing list is a place to discuss any issues related to the usage of Docutils and reStructuredText. (Please be sure to check the FAQ first.)

There are several possibilities to read and post messages on the mailing lists; use the one you feel most comfortable with.

- Using an email subscription. This is the traditional way; you will receive all messages sent to the mailing list via email.

- Use a newsreader with Gmane's NNTP interface (gmane.text.docutils.user on news.gmane.org).

- If you do not wish to subscribe, you can also just send an email message with your question or comment to Docutils-users@lists.sourceforge.net.

  Note in your message that you are not subscribed (to make sure that you receive copies [CCs] of any replies) or check for answers in the Docutils-users Archives.

The first time you post a message without being subscribed (also when posting via Gmane), you will receive an automatic response with the subject "Your message to Docutils-users awaits moderator approval"; this is done to prevent spam to the mailing lists. Your message will usually be approved within a few hours. To avoid duplicates, please do not resend your message using a different email address. After your first message has been approved, your email address will be added to the whitelist and future messages will be posted to the mailing list without moderation.

To see the collection of prior postings to the list, visit the Docutils-users Archives.

# Docutils-develop

Discussions about developing and extending Docutils take place on the Docutils-develop mailing list.

You can access this list via email subscription or news (gmane.text.docutils.devel); the posting address is Docutils-develop@lists.sourceforge.net.

To see the collection of prior postings to the list, visit the Docutils-develop Archives.

# Docutils-checkins

All check-ins to the Subversion repository cause a "check-in email" to the Docutils-checkins list. In order to stay informed about current development, developers are advised to monitor this mailing list.

This mailing list is for reading only; please direct any discussion about the check-ins to Docutils-develop. (For your convenience, the Reply-To header of all check-in emails points to Docutils-develop.)

This mailing list is accessible via email subscription or news (gmane.text.docutils.cvs) as well.

If you are using an email subscription and you would prefer to only receive check-in messages for changes that affect the main Docutils distribution (i.e. `trunk/docutils/*`), go to the list options page and select the "Docutils core" topic.

# Doc-SIG

The "Python Documentation Special Interest Group" (Doc-SIG) mailing list is occasionally used to discuss the usage of Docutils for Python documentation.

This mailing list can be accessed via email subscription or news (gmane.comp.python.documentation) as well. You must be subscribed in order to post messages to this mailing list.